Struct PlayerStateChangedRequest
pub struct PlayerStateChangedRequest {
pub state: i32,
}Fields
state: i32Implementations
impl PlayerStateChangedRequest
impl PlayerStateChangedRequest
pub fn state(&self) -> PlayerState
pub fn state(&self) -> PlayerState
Returns the enum value of state, or the default if the field is set to an invalid enum value.
pub fn set_state(&mut self, value: PlayerState)
pub fn set_state(&mut self, value: PlayerState)
Sets state to the provided enum value.