Enum InputType
#[repr(i32)]pub enum InputType {
Text = 0,
Number = 1,
SecureText = 2,
}Variants
Implementations
impl InputType
impl InputType
pub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
pub fn from_str_name(value: &str) -> Option<InputType>
pub fn from_str_name(value: &str) -> Option<InputType>
Creates an enum from field names used in the ProtoBuf definition.