Enum PreferenceType
#[repr(i32)]pub enum PreferenceType {
Unspecified = 0,
PathSelector = 1,
SingleFileInput = 2,
NumberInputGroup = 3,
TextInputGroup = 4,
ToggleGroup = 5,
RadioGroup = 6,
DropdownGroup = 7,
TextArrayInput = 8,
}Variants
Unspecified = 0
PathSelector = 1
SingleFileInput = 2
NumberInputGroup = 3
TextInputGroup = 4
ToggleGroup = 5
RadioGroup = 6
DropdownGroup = 7
TextArrayInput = 8
Implementations
impl PreferenceType
impl PreferenceType
impl PreferenceType
impl PreferenceType
pub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
pub fn from_str_name(value: &str) -> Option<PreferenceType>
pub fn from_str_name(value: &str) -> Option<PreferenceType>
Creates an enum from field names used in the ProtoBuf definition.