Enum PreferenceTypes
#[repr(i32)]pub enum PreferenceTypes {
DirectoryGroup = 0,
EditText = 1,
FilePicker = 2,
CheckboxGroup = 3,
ThemeSelector = 4,
Extensions = 5,
ButtonGroup = 6,
ProgressBar = 7,
TextField = 8,
InfoField = 9,
Dropdown = 10,
}Variants
DirectoryGroup = 0
EditText = 1
FilePicker = 2
CheckboxGroup = 3
ThemeSelector = 4
Extensions = 5
ButtonGroup = 6
ProgressBar = 7
TextField = 8
InfoField = 9
Dropdown = 10
Implementations
impl PreferenceTypes
impl PreferenceTypes
impl PreferenceTypes
impl PreferenceTypes
pub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
pub fn from_str_name(value: &str) -> Option<PreferenceTypes>
pub fn from_str_name(value: &str) -> Option<PreferenceTypes>
Creates an enum from field names used in the ProtoBuf definition.