Event

Enum Event 

pub enum Event {
Show 31 variants RequestedPlaylists(RequestedPlaylistsRequest), RequestedPlaylistSongs(RequestedPlaylistSongsRequest), OauthCallback(OauthCallbackRequest), SongQueueChanged(SongQueueChangedRequest), Seeked(SeekedRequest), VolumeChanged(VolumeChangedRequest), PlayerStateChanged(PlayerStateChangedRequest), SongChanged(SongChangedRequest), PreferenceChanged(PreferenceChangedRequest), PlaybackDetailsRequested(PlaybackDetailsRequestedRequest), CustomRequest(CustomRequest), RequestedSongFromUrl(RequestedSongFromUrlRequest), RequestedPlaylistFromUrl(RequestedPlaylistFromUrlRequest), RequestedSearchResult(RequestedSearchResultRequest), RequestedRecommendations(RequestedRecommendationsRequest), RequestedLyrics(RequestedLyricsRequest), RequestedArtistSongs(RequestedArtistSongsRequest), RequestedAlbumSongs(RequestedAlbumSongsRequest), SongAdded(SongAddedRequest), SongRemoved(SongRemovedRequest), PlaylistAdded(PlaylistAddedRequest), PlaylistRemoved(PlaylistRemovedRequest), RequestedSongFromId(RequestedSongFromIdRequest), GetRemoteUrl(GetRemoteUrlRequest), Scrobble(ScrobbleRequest), RequestedSongContextMenu(RequestedSongContextMenuRequest), RequestedPlaylistContextMenu(RequestedPlaylistContextMenuRequest), ContextMenuAction(ContextMenuActionRequest), GetProviderScopes(GetProviderScopesRequest), GetAccounts(GetAccountsRequest), PerformAccountLogin(PerformAccountLoginRequest),
}

Variants



RequestedPlaylists(RequestedPlaylistsRequest)



RequestedPlaylistSongs(RequestedPlaylistSongsRequest)



OauthCallback(OauthCallbackRequest)



SongQueueChanged(SongQueueChangedRequest)



Seeked(SeekedRequest)



VolumeChanged(VolumeChangedRequest)



PlayerStateChanged(PlayerStateChangedRequest)



SongChanged(SongChangedRequest)



PreferenceChanged(PreferenceChangedRequest)



PlaybackDetailsRequested(PlaybackDetailsRequestedRequest)



CustomRequest(CustomRequest)



RequestedSongFromUrl(RequestedSongFromUrlRequest)



RequestedPlaylistFromUrl(RequestedPlaylistFromUrlRequest)



RequestedSearchResult(RequestedSearchResultRequest)



RequestedRecommendations(RequestedRecommendationsRequest)



RequestedLyrics(RequestedLyricsRequest)



RequestedArtistSongs(RequestedArtistSongsRequest)



RequestedAlbumSongs(RequestedAlbumSongsRequest)



SongAdded(SongAddedRequest)



SongRemoved(SongRemovedRequest)



PlaylistAdded(PlaylistAddedRequest)



PlaylistRemoved(PlaylistRemovedRequest)



RequestedSongFromId(RequestedSongFromIdRequest)



GetRemoteUrl(GetRemoteUrlRequest)



Scrobble(ScrobbleRequest)



RequestedSongContextMenu(RequestedSongContextMenuRequest)



RequestedPlaylistContextMenu(RequestedPlaylistContextMenuRequest)



ContextMenuAction(ContextMenuActionRequest)



GetProviderScopes(GetProviderScopesRequest)



GetAccounts(GetAccountsRequest)



PerformAccountLogin(PerformAccountLoginRequest)

Implementations



impl Event

pub fn encode(&self, buf: &mut impl BufMut)

Encodes the message to a buffer.

pub fn merge( field: &mut Option<Event>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>

Decodes an instance of the message from a buffer, and merges it into self.

pub fn encoded_len(&self) -> usize

Returns the encoded length of the message without a length delimiter.