Response

Enum Response 

pub enum Response {
Show 31 variants RequestedPlaylists(RequestedPlaylistsResponse), RequestedPlaylistSongs(RequestedPlaylistSongsResponse), OauthCallback(OauthCallbackResponse), SongQueueChanged(SongQueueChangedResponse), Seeked(SeekedResponse), VolumeChanged(VolumeChangedResponse), PlayerStateChanged(PlayerStateChangedResponse), SongChanged(SongChangedResponse), PreferenceChanged(PreferenceChangedResponse), PlaybackDetailsRequested(PlaybackDetailsRequestedResponse), CustomRequest(CustomRequestResponse), RequestedSongFromUrl(RequestedSongFromUrlResponse), RequestedPlaylistFromUrl(RequestedPlaylistFromUrlResponse), RequestedSearchResult(RequestedSearchResultResponse), RequestedRecommendations(RequestedRecommendationsResponse), RequestedLyrics(RequestedLyricsResponse), RequestedArtistSongs(RequestedArtistSongsResponse), RequestedAlbumSongs(RequestedAlbumSongsResponse), SongAdded(SongAddedResponse), SongRemoved(SongRemovedResponse), PlaylistAdded(PlaylistAddedResponse), PlaylistRemoved(PlaylistRemovedResponse), RequestedSongFromId(RequestedSongFromIdResponse), GetRemoteUrl(GetRemoteUrlResponse), Scrobble(ScrobbleResponse), RequestedSongContextMenu(RequestedSongContextMenuResponse), RequestedPlaylistContextMenu(RequestedPlaylistContextMenuResponse), ContextMenuAction(ContextMenuActionResponse), GetProviderScopes(GetProviderScopesResponse), GetAccounts(GetAccountsResponse), PerformAccountLogin(PerformAccountLoginResponse),
}

Variants



RequestedPlaylists(RequestedPlaylistsResponse)



RequestedPlaylistSongs(RequestedPlaylistSongsResponse)



OauthCallback(OauthCallbackResponse)



SongQueueChanged(SongQueueChangedResponse)



Seeked(SeekedResponse)



VolumeChanged(VolumeChangedResponse)



PlayerStateChanged(PlayerStateChangedResponse)



SongChanged(SongChangedResponse)



PreferenceChanged(PreferenceChangedResponse)



PlaybackDetailsRequested(PlaybackDetailsRequestedResponse)



CustomRequest(CustomRequestResponse)



RequestedSongFromUrl(RequestedSongFromUrlResponse)



RequestedPlaylistFromUrl(RequestedPlaylistFromUrlResponse)



RequestedSearchResult(RequestedSearchResultResponse)



RequestedRecommendations(RequestedRecommendationsResponse)



RequestedLyrics(RequestedLyricsResponse)



RequestedArtistSongs(RequestedArtistSongsResponse)



RequestedAlbumSongs(RequestedAlbumSongsResponse)



SongAdded(SongAddedResponse)



SongRemoved(SongRemovedResponse)



PlaylistAdded(PlaylistAddedResponse)



PlaylistRemoved(PlaylistRemovedResponse)



RequestedSongFromId(RequestedSongFromIdResponse)



GetRemoteUrl(GetRemoteUrlResponse)



Scrobble(ScrobbleResponse)



RequestedSongContextMenu(RequestedSongContextMenuResponse)



RequestedPlaylistContextMenu(RequestedPlaylistContextMenuResponse)



ContextMenuAction(ContextMenuActionResponse)



GetProviderScopes(GetProviderScopesResponse)



GetAccounts(GetAccountsResponse)



PerformAccountLogin(PerformAccountLoginResponse)

Implementations



impl Response

pub fn encode(&self, buf: &mut impl BufMut)

Encodes the message to a buffer.

pub fn merge( field: &mut Option<Response>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>

Decodes an instance of the message from a buffer, and merges it into self.

pub fn encoded_len(&self) -> usize

Returns the encoded length of the message without a length delimiter.