Command

Enum Command 

pub enum Command {
Show 23 variants GetSong(GetSongRequest), GetEntity(GetEntityRequest), GetCurrentSong(GetCurrentSongRequest), GetPlayerState(GetPlayerStateRequest), GetVolume(GetVolumeRequest), GetTime(GetTimeRequest), GetQueue(GetQueueRequest), GetPreference(GetPreferenceRequest), SetPreference(SetPreferenceRequest), GetSecure(GetSecureRequest), SetSecure(SetSecureRequest), AddSongs(AddSongsRequest), RemoveSong(RemoveSongRequest), UpdateSong(UpdateSongRequest), AddPlaylist(AddPlaylistRequest), AddToPlaylist(AddToPlaylistRequest), RegisterOauth(RegisterOauthRequest), OpenExternalUrl(OpenExternalUrlRequest), UpdateAccounts(UpdateAccountsRequest), RegisterUserPreference(RegisterUserPreferenceRequest), UnregisterUserPreference(UnregisterUserPreferenceRequest), ExtensionsUpdated(ExtensionsUpdatedRequest), GetAppVersion(GetAppVersionRequest),
}

Variants



GetSong(GetSongRequest)



GetEntity(GetEntityRequest)



GetCurrentSong(GetCurrentSongRequest)



GetPlayerState(GetPlayerStateRequest)



GetVolume(GetVolumeRequest)



GetTime(GetTimeRequest)



GetQueue(GetQueueRequest)



GetPreference(GetPreferenceRequest)



SetPreference(SetPreferenceRequest)



GetSecure(GetSecureRequest)



SetSecure(SetSecureRequest)



AddSongs(AddSongsRequest)



RemoveSong(RemoveSongRequest)



UpdateSong(UpdateSongRequest)



AddPlaylist(AddPlaylistRequest)



AddToPlaylist(AddToPlaylistRequest)



RegisterOauth(RegisterOauthRequest)



OpenExternalUrl(OpenExternalUrlRequest)



UpdateAccounts(UpdateAccountsRequest)



RegisterUserPreference(RegisterUserPreferenceRequest)



UnregisterUserPreference(UnregisterUserPreferenceRequest)



ExtensionsUpdated(ExtensionsUpdatedRequest)



GetAppVersion(GetAppVersionRequest)

Implementations



impl Command

pub fn encode(&self, buf: &mut impl BufMut)

Encodes the message to a buffer.

pub fn merge( field: &mut Option<Command>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>

Decodes an instance of the message from a buffer, and merges it into self.

pub fn encoded_len(&self) -> usize

Returns the encoded length of the message without a length delimiter.