Struct PreferenceItem
pub struct PreferenceItem {
pub id: String,
pub pref_type: i32,
pub title: String,
pub subtitle: String,
pub placeholder: Option<String>,
pub validation: String,
pub options: Vec<PreferenceOption>,
pub value: Option<PreferenceValue>,
pub default: Option<PreferenceValue>,
}Fields
id: Stringpref_type: i32title: Stringsubtitle: Stringplaceholder: Option<String>validation: Stringoptions: Vec<PreferenceOption>value: Option<PreferenceValue>default: Option<PreferenceValue>Implementations
impl PreferenceItem
impl PreferenceItem
pub fn pref_type(&self) -> PreferenceType
pub fn pref_type(&self) -> PreferenceType
Returns the enum value of pref_type, or the default if the field is set to an invalid enum value.
pub fn set_pref_type(&mut self, value: PreferenceType)
pub fn set_pref_type(&mut self, value: PreferenceType)
Sets pref_type to the provided enum value.
pub fn placeholder(&self) -> &str
pub fn placeholder(&self) -> &str
Returns the value of placeholder, or the default value if placeholder is unset.