Struct PreferenceUiData
pub struct PreferenceUiData {
pub type: i32,
pub title: String,
pub key: String,
pub description: String,
pub input_type: Option<i32>,
pub single: Option<bool>,
pub items: Vec<CheckboxItem>,
pub default: Option<Struct>,
pub mobile: Option<bool>,
}Fields
type: i32title: Stringkey: Stringdescription: Stringinput_type: Option<i32>single: Option<bool>items: Vec<CheckboxItem>default: Option<Struct>mobile: Option<bool>Implementations
impl PreferenceUiData
impl PreferenceUiData
pub fn type(&self) -> PreferenceTypes
pub fn type(&self) -> PreferenceTypes
Returns the enum value of type, or the default if the field is set to an invalid enum value.
pub fn set_type(&mut self, value: PreferenceTypes)
pub fn set_type(&mut self, value: PreferenceTypes)
Sets type to the provided enum value.
pub fn input_type(&self) -> InputType
pub fn input_type(&self) -> InputType
Returns the enum value of input_type, or the default if the field is unset or set to an invalid enum value.
pub fn set_input_type(&mut self, value: InputType)
pub fn set_input_type(&mut self, value: InputType)
Sets input_type to the provided enum value.