Struct RequestedSearchResultResponse
pub struct RequestedSearchResultResponse {
pub songs: Vec<Song>,
pub playlists: Vec<Playlist>,
pub artists: Vec<Artist>,
pub albums: Vec<Album>,
}Fields
songs: Vec<Song>playlists: Vec<Playlist>artists: Vec<Artist>albums: Vec<Album>Trait Implementations
impl Clone for RequestedSearchResultResponse
impl Clone for RequestedSearchResultResponse
fn clone(&self) -> RequestedSearchResultResponse
fn clone(&self) -> RequestedSearchResultResponse
Returns a duplicate of the value. Read more
1.0.0fn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Debug for RequestedSearchResultResponse
impl Debug for RequestedSearchResultResponse
impl Default for RequestedSearchResultResponse
impl Default for RequestedSearchResultResponse
fn default() -> RequestedSearchResultResponse
fn default() -> RequestedSearchResultResponse
Returns the “default value” for a type. Read more
impl Message for RequestedSearchResultResponse
impl Message for RequestedSearchResultResponse
fn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read morefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.impl PartialEq for RequestedSearchResultResponse
impl PartialEq for RequestedSearchResultResponse
impl StructuralPartialEq for RequestedSearchResultResponse