Struct SearchableSong
pub struct SearchableSong {
pub id: Option<String>,
pub path: Option<String>,
pub title: Option<String>,
pub sample_rate: Option<f64>,
pub hash: Option<String>,
pub type: Option<i32>,
pub url: Option<String>,
pub playback_url: Option<String>,
pub provider_extension: Option<String>,
pub show_in_library: Option<bool>,
}Fields
id: Option<String>path: Option<String>title: Option<String>sample_rate: Option<f64>hash: Option<String>type: Option<i32>url: Option<String>playback_url: Option<String>provider_extension: Option<String>show_in_library: Option<bool>Implementations
impl SearchableSong
impl SearchableSong
pub fn sample_rate(&self) -> f64
pub fn sample_rate(&self) -> f64
Returns the value of sample_rate, or the default value if sample_rate is unset.
pub fn type(&self) -> SongType
pub fn type(&self) -> SongType
Returns the enum value of type, or the default if the field is unset or set to an invalid enum value.
pub fn playback_url(&self) -> &str
pub fn playback_url(&self) -> &str
Returns the value of playback_url, or the default value if playback_url is unset.
pub fn provider_extension(&self) -> &str
pub fn provider_extension(&self) -> &str
Returns the value of provider_extension, or the default value if provider_extension is unset.
pub fn show_in_library(&self) -> bool
pub fn show_in_library(&self) -> bool
Returns the value of show_in_library, or the default value if show_in_library is unset.