Struct ThemeDetails
pub struct ThemeDetails {
pub id: String,
pub name: String,
pub author: Option<String>,
pub theme: Option<ThemeItem>,
pub description: Option<String>,
}Fields
id: Stringname: Stringtheme: Option<ThemeItem>description: Option<String>Implementations
impl ThemeDetails
impl ThemeDetails
Returns the value of author, or the default value if author is unset.
pub fn description(&self) -> &str
pub fn description(&self) -> &str
Returns the value of description, or the default value if description is unset.