Struct InnerSong
pub struct InnerSong {Show 21 fields
pub id: Option<String>,
pub path: Option<String>,
pub size: Option<f64>,
pub title: Option<String>,
pub date: Option<String>,
pub year: Option<String>,
pub lyrics: Option<String>,
pub release_type: Option<String>,
pub bitrate: Option<f64>,
pub codec: Option<String>,
pub container: Option<String>,
pub duration: Option<Duration>,
pub sample_rate: Option<f64>,
pub hash: Option<String>,
pub type: i32,
pub url: Option<String>,
pub song_cover_path_high: Option<String>,
pub playback_url: Option<String>,
pub song_cover_path_low: Option<String>,
pub date_added: Option<i64>,
pub track_no: Option<f64>,
}Fields
id: Option<String>_id
path: Option<String>size: Option<f64>title: Option<String>date: Option<String>year: Option<String>lyrics: Option<String>release_type: Option<String>bitrate: Option<f64>codec: Option<String>container: Option<String>duration: Option<Duration>sample_rate: Option<f64>hash: Option<String>type: i32url: Option<String>song_cover_path_high: Option<String>playback_url: Option<String>song_cover_path_low: Option<String>date_added: Option<i64>track_no: Option<f64>Implementations
impl InnerSong
impl InnerSong
pub fn release_type(&self) -> &str
pub fn release_type(&self) -> &str
Returns the value of release_type, or the default value if release_type is unset.
pub fn container(&self) -> &str
pub fn container(&self) -> &str
Returns the value of container, or the default value if container is unset.
pub fn sample_rate(&self) -> f64
pub fn sample_rate(&self) -> f64
Returns the value of sample_rate, or the default value if sample_rate is unset.
pub fn type(&self) -> SongType
pub fn type(&self) -> SongType
Returns the enum value of type, or the default if the field is set to an invalid enum value.
pub fn song_cover_path_high(&self) -> &str
pub fn song_cover_path_high(&self) -> &str
Returns the value of song_cover_path_high, or the default value if song_cover_path_high is unset.
pub fn playback_url(&self) -> &str
pub fn playback_url(&self) -> &str
Returns the value of playback_url, or the default value if playback_url is unset.
pub fn song_cover_path_low(&self) -> &str
pub fn song_cover_path_low(&self) -> &str
Returns the value of song_cover_path_low, or the default value if song_cover_path_low is unset.
pub fn date_added(&self) -> i64
pub fn date_added(&self) -> i64
Returns the value of date_added, or the default value if date_added is unset.